Phone Input Challenge

← Back to Challenges
phone-input
Enter the phone number 555-1234 in this (deliberately misbehaving) input field
This input field is designed to be difficult. It will ignore your first keystroke. Keep trying to enter "555-1234" to complete the challenge.
⚠️ This input field ignores the first keystroke each time it's focused!
✅ Challenge completed successfully! You entered the phone number despite the misbehaving input.